# Generated by Django 2.1.7 on 2019-02-25 21:53

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('spider_verifier', '0003_1_linked_hashes_stub'),
    ]

    operations = [
        migrations.CreateModel(
            name='VerifySourceObject',
            fields=[
                ('id', models.BigAutoField(editable=False, primary_key=True, serialize=False)),
                ('url', models.URLField(db_index=True, max_length=400, unique=True)),
                ('get_params', models.TextField()),
            ],
        ),
        migrations.AlterField(
            model_name='dataverificationtag',
            name='verification_state',
            field=models.CharField(choices=[('retrieve', 'retrieval pending'), ('pending', 'pending'), ('verified', 'verified'), ('invalid', 'invalid'), ('rejected', 'rejected')], default='retrieve', max_length=10),
        ),
        migrations.AddField(
            model_name='dataverificationtag',
            name='source',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='spider_verifier.VerifySourceObject'),
        ),
    ]
